FragPipe-SpecLib: Simple library generation for FragPipe
================================================

FragPipe-SpecLib is a fork of [EasyPQP](https://github.com/grosenberger/easypqp). It is used by [FragPipe](https://github.com/Nesvilab/FragPipe) to build spectral library.

Installation
============

The Windows version of FragPipe has FragPipe-SpecLib bundled.
For the Linux version, install the production version:

```
pip install FragPipe-SpecLib
```

Install the development version from GitHub:

````
pip install git+https://github.com/Nesvilab/FragPipe-SpecLib.git@master
````
